@@ -27,28 +27,38 @@ from .literals import (
 )
 from .type_defs import (
     BatchCreateChannelMembershipResponseTypeDef,
+    ChannelFlowCallbackResponseTypeDef,
+    ChannelMessageCallbackTypeDef,
     CreateChannelBanResponseTypeDef,
+    CreateChannelFlowResponseTypeDef,
     CreateChannelMembershipResponseTypeDef,
     CreateChannelModeratorResponseTypeDef,
     CreateChannelResponseTypeDef,
     DescribeChannelBanResponseTypeDef,
+    DescribeChannelFlowResponseTypeDef,
     DescribeChannelMembershipForAppInstanceUserResponseTypeDef,
     DescribeChannelMembershipResponseTypeDef,
     DescribeChannelModeratedByAppInstanceUserResponseTypeDef,
     DescribeChannelModeratorResponseTypeDef,
     DescribeChannelResponseTypeDef,
     GetChannelMessageResponseTypeDef,
+    GetChannelMessageStatusResponseTypeDef,
     GetMessagingSessionEndpointResponseTypeDef,
     ListChannelBansResponseTypeDef,
+    ListChannelFlowsResponseTypeDef,
     ListChannelMembershipsForAppInstanceUserResponseTypeDef,
     ListChannelMembershipsResponseTypeDef,
     ListChannelMessagesResponseTypeDef,
     ListChannelModeratorsResponseTypeDef,
+    ListChannelsAssociatedWithChannelFlowResponseTypeDef,
     ListChannelsModeratedByAppInstanceUserResponseTypeDef,
     ListChannelsResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
+    ProcessorTypeDef,
     RedactChannelMessageResponseTypeDef,
     SendChannelMessageResponseTypeDef,
     TagTypeDef,
+    UpdateChannelFlowResponseTypeDef,
     UpdateChannelMessageResponseTypeDef,
     UpdateChannelReadMarkerResponseTypeDef,
     UpdateChannelResponseTypeDef,
@@ -80,7 +90,7 @@ class Exceptions:
 
 class ChimeSDKMessagingClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html)
     """
 
@@ -92,6 +102,16 @@ class ChimeSDKMessagingClient(BaseClient):
         ChimeSDKMessagingClient exceptions.
         """
 
+    def associate_channel_flow(
+        self, *, ChannelArn: str, ChannelFlowArn: str, ChimeBearer: str
+    ) -> None:
+        """
+        Associates a channel flow with a channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.associate_channel_flow)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#associate_channel_flow)
+        """
+
     def batch_create_channel_membership(
         self,
         *,
@@ -103,7 +123,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Adds a specified number of users to a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.batch_create_channel_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.batch_create_channel_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#batch_create_channel_membership)
         """
 
@@ -111,10 +131,25 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#can_paginate)
         """
 
+    def channel_flow_callback(
+        self,
+        *,
+        CallbackId: str,
+        ChannelArn: str,
+        ChannelMessage: "ChannelMessageCallbackTypeDef",
+        DeleteResource: bool = ...
+    ) -> ChannelFlowCallbackResponseTypeDef:
+        """
+        Calls back Chime SDK Messaging with a processing response message.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.channel_flow_callback)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#channel_flow_callback)
+        """
+
     def create_channel(
         self,
         *,
@@ -130,7 +165,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Creates a channel to which you can add users and send messages.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#create_channel)
         """
 
@@ -140,17 +175,33 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Permanently bans a member from a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_ban)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_ban)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#create_channel_ban)
         """
 
+    def create_channel_flow(
+        self,
+        *,
+        AppInstanceArn: str,
+        Processors: Sequence["ProcessorTypeDef"],
+        Name: str,
+        ClientRequestToken: str,
+        Tags: Sequence["TagTypeDef"] = ...
+    ) -> CreateChannelFlowResponseTypeDef:
+        """
+        Creates a channel flow, a container for processors.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_flow)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#create_channel_flow)
+        """
+
     def create_channel_membership(
         self, *, ChannelArn: str, MemberArn: str, Type: ChannelMembershipTypeType, ChimeBearer: str
     ) -> CreateChannelMembershipResponseTypeDef:
         """
         Adds a user to a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#create_channel_membership)
         """
 
@@ -160,7 +211,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Creates a new `ChannelModerator`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_moderator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_moderator)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#create_channel_moderator)
         """
 
@@ -169,7 +220,7 @@ class ChimeSDKMessagingClient(BaseClient):
         Immediately makes a channel and its memberships inaccessible and marks them for
         deletion.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#delete_channel)
         """
 
@@ -177,17 +228,25 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Removes a user from a channel's ban list.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_ban)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_ban)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#delete_channel_ban)
         """
 
+    def delete_channel_flow(self, *, ChannelFlowArn: str) -> None:
+        """
+        Deletes a channel flow, an irreversible process.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_flow)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#delete_channel_flow)
+        """
+
     def delete_channel_membership(
         self, *, ChannelArn: str, MemberArn: str, ChimeBearer: str
     ) -> None:
         """
         Removes a member from a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#delete_channel_membership)
         """
 
@@ -195,7 +254,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Deletes a channel message.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#delete_channel_message)
         """
 
@@ -205,7 +264,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Deletes a channel moderator.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_moderator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_moderator)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#delete_channel_moderator)
         """
 
@@ -215,7 +274,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Returns the full details of a channel in an Amazon Chime `AppInstance` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel)
         """
 
@@ -225,17 +284,25 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Returns the full details of a channel ban.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_ban)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_ban)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel_ban)
         """
 
+    def describe_channel_flow(self, *, ChannelFlowArn: str) -> DescribeChannelFlowResponseTypeDef:
+        """
+        Returns the full details of a channel flow in an Amazon Chime `AppInstance`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_flow)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel_flow)
+        """
+
     def describe_channel_membership(
         self, *, ChannelArn: str, MemberArn: str, ChimeBearer: str
     ) -> DescribeChannelMembershipResponseTypeDef:
         """
         Returns the full details of a user's channel membership.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel_membership)
         """
 
@@ -246,7 +313,7 @@ class ChimeSDKMessagingClient(BaseClient):
         Returns the details of a channel based on the membership of the specified
         `AppInstanceUser` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_membership_for_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_membership_for_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel_membership_for_app_instance_user)
         """
 
@@ -257,7 +324,7 @@ class ChimeSDKMessagingClient(BaseClient):
         Returns the full details of a channel moderated by the specified
         `AppInstanceUser` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_moderated_by_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_moderated_by_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel_moderated_by_app_instance_user)
         """
 
@@ -267,10 +334,20 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Returns the full details of a single ChannelModerator.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_moderator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_moderator)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel_moderator)
         """
 
+    def disassociate_channel_flow(
+        self, *, ChannelArn: str, ChannelFlowArn: str, ChimeBearer: str
+    ) -> None:
+        """
+        Disassociates a channel flow from all its channels.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.disassociate_channel_flow)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#disassociate_channel_flow)
+        """
+
     def generate_presigned_url(
         self,
         ClientMethod: str,
@@ -281,7 +358,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#generate_presigned_url)
         """
 
@@ -291,15 +368,25 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Gets the full details of a channel message.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.get_channel_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.get_channel_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#get_channel_message)
         """
 
+    def get_channel_message_status(
+        self, *, ChannelArn: str, MessageId: str, ChimeBearer: str
+    ) -> GetChannelMessageStatusResponseTypeDef:
+        """
+        Gets message status for a specified `messageId`.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.get_channel_message_status)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#get_channel_message_status)
+        """
+
     def get_messaging_session_endpoint(self) -> GetMessagingSessionEndpointResponseTypeDef:
         """
         The details of the endpoint for the messaging session.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.get_messaging_session_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.get_messaging_session_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#get_messaging_session_endpoint)
         """
 
@@ -309,10 +396,20 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Lists all the users banned from a particular channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_bans)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_bans)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channel_bans)
         """
 
+    def list_channel_flows(
+        self, *, AppInstanceArn: str, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListChannelFlowsResponseTypeDef:
+        """
+        Returns a paginated lists of all the channel flows created under a single Chime.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_flows)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channel_flows)
+        """
+
     def list_channel_memberships(
         self,
         *,
@@ -325,7 +422,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Lists all channel memberships in a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_memberships)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_memberships)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channel_memberships)
         """
 
@@ -340,7 +437,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Lists all channels that a particular `AppInstanceUser` is a part of.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_memberships_for_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_memberships_for_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channel_memberships_for_app_instance_user)
         """
 
@@ -358,7 +455,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         List all the messages in a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_messages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_messages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channel_messages)
         """
 
@@ -368,7 +465,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Lists all the moderators for a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_moderators)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_moderators)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channel_moderators)
         """
 
@@ -384,10 +481,20 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Lists all Channels created under a single Chime App as a paginated list.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channels)
         """
 
+    def list_channels_associated_with_channel_flow(
+        self, *, ChannelFlowArn: str, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListChannelsAssociatedWithChannelFlowResponseTypeDef:
+        """
+        Lists all channels associated with a specified channel flow.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channels_associated_with_channel_flow)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channels_associated_with_channel_flow)
+        """
+
     def list_channels_moderated_by_app_instance_user(
         self,
         *,
@@ -399,17 +506,25 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         A list of the channels moderated by an `AppInstanceUser` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channels_moderated_by_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channels_moderated_by_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channels_moderated_by_app_instance_user)
         """
 
+    def list_tags_for_resource(self, *, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
+        """
+        Lists the tags applied to an Amazon Chime SDK messaging resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_tags_for_resource)
+        """
+
     def redact_channel_message(
         self, *, ChannelArn: str, MessageId: str, ChimeBearer: str
     ) -> RedactChannelMessageResponseTypeDef:
         """
         Redacts message content, but not metadata.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.redact_channel_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.redact_channel_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#redact_channel_message)
         """
 
@@ -427,10 +542,27 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Sends a message to a particular channel that the member is a part of.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.send_channel_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.send_channel_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#send_channel_message)
         """
 
+    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> None:
+        """
+        Applies the specified tags to the specified Amazon Chime SDK messaging resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.tag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#tag_resource)
+        """
+
+    def untag_resource(self, *, ResourceARN: str, TagKeys: Sequence[str]) -> None:
+        """
+        Removes the specified tags from the specified Amazon Chime SDK messaging
+        resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.untag_resource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#untag_resource)
+        """
+
     def update_channel(
         self,
         *,
@@ -443,10 +575,20 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Update a channel's attributes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#update_channel)
         """
 
+    def update_channel_flow(
+        self, *, ChannelFlowArn: str, Processors: Sequence["ProcessorTypeDef"], Name: str
+    ) -> UpdateChannelFlowResponseTypeDef:
+        """
+        Updates channel flow attributes.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel_flow)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#update_channel_flow)
+        """
+
     def update_channel_message(
         self,
         *,
@@ -459,7 +601,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Updates the content of a message.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#update_channel_message)
         """
 
@@ -469,6 +611,6 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         The details of the time when a user last read messages in a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.64/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel_read_marker)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.65/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel_read_marker)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#update_channel_read_marker)
         """
