@@ -22,10 +22,13 @@ else:
 __all__ = (
     "ChannelMembershipTypeType",
     "ChannelMessagePersistenceTypeType",
+    "ChannelMessageStatusType",
     "ChannelMessageTypeType",
     "ChannelModeType",
     "ChannelPrivacyType",
     "ErrorCodeType",
+    "FallbackActionType",
+    "InvocationTypeType",
     "SortOrderType",
     "ServiceName",
 )
@@ -33,6 +36,7 @@ __all__ = (
 
 ChannelMembershipTypeType = Literal["DEFAULT", "HIDDEN"]
 ChannelMessagePersistenceTypeType = Literal["NON_PERSISTENT", "PERSISTENT"]
+ChannelMessageStatusType = Literal["DENIED", "FAILED", "PENDING", "SENT"]
 ChannelMessageTypeType = Literal["CONTROL", "STANDARD"]
 ChannelModeType = Literal["RESTRICTED", "UNRESTRICTED"]
 ChannelPrivacyType = Literal["PRIVATE", "PUBLIC"]
@@ -53,6 +57,8 @@ ErrorCodeType = Literal[
     "Unprocessable",
     "VoiceConnectorGroupAssociationsExist",
 ]
+FallbackActionType = Literal["ABORT", "CONTINUE"]
+InvocationTypeType = Literal["ASYNC"]
 SortOrderType = Literal["ASCENDING", "DESCENDING"]
 ServiceName = Literal[
     "accessanalyzer",
